VESPA
-----

Validation of Exoplanet Signals using a Probabilistic Algorithm--- calculating false positive probabilities for transit signals

This code is will be a publicly available and general-purpose implementation of the Morton (2012) false-positive calculating procedure.  Currently under construction.
